#
# spec file for package hiredis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libname lib%{name}1_1_0
Name:           hiredis
Version:        1.1.0
Release:        1.3
Summary:        Minimalistic C client for Redis
License:        BSD-3-Clause
Group:          Productivity/Databases/Clients
URL:            https://github.com/redis/hiredis
Source0:        https://github.com/redis/hiredis/archive/v%{version}.tar.gz
Patch0:         relocatable_executable.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)

%description
Hiredis is a minimalistic C client library for the
Redis database.

%package devel
Summary:        Header files and libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
The %{name}-devel package contains the header files and
libraries for Redis database.

%package -n %{libname}
Summary:        Shared library for %{name}
Group:          Productivity/Databases/Clients

%description -n %{libname}
Shared library for %{name}. The %{name}-example and
%{name}-test are in %{name} package.

%prep
%setup -q
%patch0

%build
%make_build \
	OPTIMIZATION="%{optflags}" \
	PREFIX=%{_prefix} \
	LIBRARY_PATH=%{_lib} \
	USE_SSL=1

%install
%make_install \
	PREFIX=%{_prefix} \
	LIBRARY_PATH=%{_lib} \
	USE_SSL=1

mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{name}-test %{buildroot}%{_bindir}

find %{buildroot} -type f -name '*.a' -delete

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license COPYING
%doc README.md
%attr(0755,root,root) %{_bindir}/%{name}-test

%files devel
%license COPYING
%doc CHANGELOG.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_ssl.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}_ssl.pc

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}.so.*
%{_libdir}/lib%{name}_ssl.so.*

%changelog
* Mon Jan  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- hiredis 1.1.0:
  * better SSL convenience
  * new async adapters
  * can now return nan in addition to -inf and inf in a
    REDIS_REPLY_DOUBLE. Applications that deal with RESP3 doubles
    should make sure to account for this.
* Thu Oct  7 2021 Paul Fee <paul.fee@jci.com>
- hiredis 1.0.2
  * Hiredis v1.0.2 is a security release with a fix for CVE-2021-32765.
    [boo#1191331]
    v1.0.1 erroneously bumped the SONAME so should be skipped.
* Wed Oct  6 2021 Andreas Stieger <andreas.stieger@gmx.de>
- hiredis 1.0.1:
  * CVE-2021-32765: integer overflow if provided maliciously
    crafted or corrupted RESP mult-bulk protocol data boo#1191331
* Tue Oct  6 2020 Paul Fee <paul.fee@jci.com>
- Enable TLS
* Fri Oct  2 2020 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file with spec-cleaner
* Mon Sep 28 2020 paul.fee@jci.com
- Update to 1.0.0
  * The first stable release of Hiredis.
  * RESP3 support, TLS connections, allocator injection.
  * Connect and command timeouts.
  * API breaking changes, recompilation required.
- Update to 0.14.1
  * CVE-2020-7105 (failure to check for NULL return when
    allocating memory).
- Update to 0.14.0
  * ABI changes.  Upstream "changes are numerous".
- Add relocatable_executable.patch
* Sun Nov 22 2015 mpluskal@suse.com
- Update to 0.13.3
  * Revert "Clear `REDIS_CONNECTED` flag when connection is
  closed".
  * Make tests pass on FreeBSD
- Changes for 0.13.2
  * Prevent crash on pending replies in async code
  * Clear `REDIS_CONNECTED` flag when connection is closed
  * Add MacOS X addapter
  * Add Qt adapter
  * Add Ivykis adapter
- Changes for 0.13.1
  * Fix memory leak in async reply handling
  * Rename struct member to avoid name clash with pre-c99 code
- Changes for 0.13.0
  * Windows compatibility layer for parser code
  * Properly escape data printed to PKGCONF file
  * Fix tests when assert() undefined
  * Implement a reconnect method for the client context, this
  changes the structure of `redisContext`
- Drop hiredis-pkgconfig.patch
  * fixed in upstream
* Tue Mar  3 2015 dimstar@opensuse.org
- Add hiredis-pkgconfig.patch: Fix generation of .pc file.
- Pass PREFIX and LIBRARY_PATH (lib/lib64) to make (and make
  install): the build phase needs this info for the .pc file
  generation.
- Make use of the new DESTDIR support.
* Mon Mar  2 2015 mpluskal@suse.com
- Update to 0.12.1
  * Fix `make install`: DESTDIR support, install all required
    files, install PKGCONF in proper location
  * Fix `make test` as 32 bit build on 64 bit platform
- Changes for  0.12.0
  * Add optional KeepAlive support
  * Try again on EINTR errors
  * Add libuv adapter
  * Add IPv6 support
  * Remove possiblity of multiple close on same fd
  * Add ability to bind source address on connect
  * Add redisConnectFd() and redisFreeKeepFd()
  * Fix getaddrinfo() memory leak
  * Free string if it is unused (fixes memory leak)
  * Improve redisAppendCommandArgv performance 2.5x
  * Add support for SO_REUSEADDR
  * Fix redisvFormatCommand format parsing
  * Add GLib 2.0 adapter
  * Refactor reading code into read.c
  * Fix errno error buffers to not clobber errors
  * Generate pkgconf during build
  * Silence _BSD_SOURCE warnings
  * Improve digit counting for multibulk creation
* Tue Aug 20 2013 mvyskocil@suse.com
- Package hiredis 0.11.0 for openSUSE
